==> cds-services-impl-2.10.6-sources.jar: com/sap/cds/services/impl/model/DynamicModelProviderConfiguration.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.model;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sap.cds.mtx.impl.ModelProviderAccess;
import com.sap.cds.mtx.impl.SidecarAccessV1;
import com.sap.cds.services.runtime.CdsRuntimeConfiguration;
import com.sap.cds.services.runtime.CdsRuntimeConfigurer;
import com.sap.cds.services.utils.model.DynamicModelUtils;
import com.sap.cloud.sdk.cloudplatform.connectivity.DefaultDestinationLoader;
import com.sap.cloud.sdk.cloudplatform.connectivity.DestinationAccessor;
import com.sap.cloud.sdk.cloudplatform.connectivity.HttpDestination;

public class DynamicModelProviderConfiguration implements CdsRuntimeConfiguration {

	private static final Logger logger = LoggerFactory.getLogger(DynamicModelProviderConfiguration.class);

	@Override
	public void providers(CdsRuntimeConfigurer configurer) {
		DynamicModelUtils utils = new DynamicModelUtils(configurer.getCdsRuntime());
		if (utils.isDynamicModelEnabled()) {
			logger.info("Loading DynamicModelProvider");
			configurer.provider(new DynamicModelProvider(configurer.getCdsRuntime()));

			HttpDestination destination = utils.createSidecarDestination(utils.isModelProviderEnabled() ?
							ModelProviderAccess.MODEL_PROVIDER_DESTINATION : SidecarAccessV1.MTX_SIDECAR_DESTINATION, utils.getModelProviderUrl());

			// TODO sync with other destinations
			DefaultDestinationLoader destinationLoader = new DefaultDestinationLoader();
			destinationLoader.registerDestination(destination);
			DestinationAccessor.prependDestinationLoader(destinationLoader);
		}
	}

}

==> cds-services-impl-3.1.1-sources.jar: com/sap/cds/services/impl/model/DynamicModelProviderConfiguration.java <==
/**************************************************************************
 * (C) 2019-2024 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.model;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.sap.cds.mtx.impl.ModelProviderAccess;
import com.sap.cds.services.runtime.CdsRuntimeConfiguration;
import com.sap.cds.services.runtime.CdsRuntimeConfigurer;
import com.sap.cds.services.utils.model.DynamicModelUtils;
import com.sap.cloud.sdk.cloudplatform.connectivity.DefaultDestinationLoader;
import com.sap.cloud.sdk.cloudplatform.connectivity.DestinationAccessor;
import com.sap.cloud.sdk.cloudplatform.connectivity.HttpDestination;

public class DynamicModelProviderConfiguration implements CdsRuntimeConfiguration {

	private static final Logger logger = LoggerFactory.getLogger(DynamicModelProviderConfiguration.class);

	@Override
	public void providers(CdsRuntimeConfigurer configurer) {
		DynamicModelUtils utils = new DynamicModelUtils(configurer.getCdsRuntime());
		if (utils.isModelProviderEnabled()) {
			logger.info("Loading DynamicModelProvider");
			configurer.provider(new DynamicModelProvider(configurer.getCdsRuntime()));

			// TODO sync with other destinations
			HttpDestination destination = utils.createSidecarDestination(ModelProviderAccess.MODEL_PROVIDER_DESTINATION, utils.getModelProviderUrl());
			DefaultDestinationLoader destinationLoader = new DefaultDestinationLoader();
			destinationLoader.registerDestination(destination);
			DestinationAccessor.prependDestinationLoader(destinationLoader);
		}
	}

}
